import requests

URL = "http://127.0.0.1:8000/images/"


def upload(file_url: str):
    files = {"image": open(file_url, 'rb')}
    response = requests.post(URL, files=files)
    return response


def rotate(image_id: str, angle=int):
    url = f"{URL}{image_id}/display/?rotate={angle}"
    response = requests.get(url)
    return response


def format_type(image_id: str, extension=str):
    url = f"{URL}{image_id}/display/?extension={extension}"
    response = requests.get(url)
    return response


def resize(image_id: str, width, height):
    url = f"{URL}{image_id}/display/?width={width}&height={height}"
    response = requests.get(url)
    return response



import setuptools
from setuptools import setup

setup(
    name='progimage-lib',
    version='0.2.0',
    description='Python package for ProgImage',
    url='https://github.com/chitnguyen169/progimage-lib',
    author='Chi Nguyen',
    author_email='chi.nguyen.gmb@gmail.com',
    packages=setuptools.find_packages(),
    install_requires=['requests==2.27.1'],

    classifiers=[
        "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
    ],
)



import io
from unittest import TestCase

import requests
from PIL import Image

from progimage.image import upload, rotate, format_type, resize


class ImageTest(TestCase):
    def test_upload(self):
        response = upload(file_url='/Users/chinguyen/workspace/progimage/media/download.jpeg')
        assert response.status_code == 200

    def test_rotate(self):
        image_id = "c99d41e5-8969-42e4-91e0-81a82e801525"
        response = rotate(image_id=image_id, angle=90)
        assert response.status_code == 200

    def test_format_type(self):
        image_id = "c99d41e5-8969-42e4-91e0-81a82e801525"
        response = format_type(image_id=image_id, extension="gif")
        new_image = Image.open(io.BytesIO(response.content))
        assert response.status_code == 200
        assert new_image.format == 'GIF'

    def test_resize(self):
        image_id = "c99d41e5-8969-42e4-91e0-81a82e801525"
        response = resize(image_id=image_id, width=100, height=200)
        new_image = Image.open(io.BytesIO(response.content))
        assert response.status_code == 200
        assert new_image.width == 100
        assert new_image.height == 200
